"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ConfigFetcher_1 = require("./ConfigFetcher");
var ConfigCatClientConfiguration_1 = require("./ConfigCatClientConfiguration");
var AutoPollConfigService_1 = require("./AutoPollConfigService");
var Cache_1 = require("./Cache");
var LazyLoadConfigService_1 = require("./LazyLoadConfigService");
var ManualPollService_1 = require("./ManualPollService");
var RolloutEvaluator_1 = require("./RolloutEvaluator");
var VERSION = require("../package.json").version;
exports.CONFIG_CHANGE_EVENT_NAME = "changed";
var ConfigCatClientImpl = /** @class */ (function () {
    function ConfigCatClientImpl(apiKey, configuration, configFetcher, cache, evaluator) {
        if (!apiKey) {
            throw new Error("Invalid 'apiKey' value");
        }
        this.apiKey = apiKey;
        if (configuration && configuration instanceof ConfigCatClientConfiguration_1.LazyLoadConfiguration) {
            var lc = configuration;
            this.configService = new LazyLoadConfigService_1.LazyLoadConfigSerivce(configFetcher ? configFetcher : new ConfigFetcher_1.HttpConfigFetcher(lc.getUrl(apiKey), "l-" + VERSION), cache ? cache : new Cache_1.InMemoryCache(), lc);
            this.evaluator = new RolloutEvaluator_1.RolloutEvaluator();
        }
        else if (configuration && configuration instanceof ConfigCatClientConfiguration_1.ManualPollConfiguration) {
            var mc = configuration;
            this.configService = new ManualPollService_1.ManualPollService(configFetcher ? configFetcher : new ConfigFetcher_1.HttpConfigFetcher(mc.getUrl(apiKey), "m-" + VERSION), cache ? cache : new Cache_1.InMemoryCache(), mc);
            this.evaluator = new RolloutEvaluator_1.RolloutEvaluator();
        }
        else {
            var ac = new ConfigCatClientConfiguration_1.AutoPollConfiguration();
            if (configuration && configuration instanceof ConfigCatClientConfiguration_1.AutoPollConfiguration) {
                ac = configuration;
            }
            var autoConfigService = new AutoPollConfigService_1.AutoPollConfigService(configFetcher ? configFetcher : new ConfigFetcher_1.HttpConfigFetcher(ac.getUrl(apiKey), "a-" + VERSION), cache ? cache : new Cache_1.InMemoryCache(), ac);
            this.configService = autoConfigService;
            this.evaluator = new RolloutEvaluator_1.RolloutEvaluator();
        }
    }
    ConfigCatClientImpl.prototype.getValue = function (key, defaultValue, user, callback) {
        var _this = this;
        this.configService.getConfig(function (value) {
            var result = defaultValue;
            result = _this.evaluator.Evaluate(value, key, defaultValue, user);
            callback(result);
        });
    };
    ConfigCatClientImpl.prototype.forceRefresh = function (callback) {
        this.configService.refreshConfig(callback);
    };
    return ConfigCatClientImpl;
}());
exports.ConfigCatClientImpl = ConfigCatClientImpl;
