"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var sha1 = require("js-sha1");
/** Object for variation evaluation */
var User = /** @class */ (function () {
    function User(identifier) {
        /** Optional dictionary for custom attributes of the User for advanced targeting rule definitions. e.g. User role, Subscription type */
        this.custom = {};
        this.identifier = identifier;
    }
    return User;
}());
exports.User = User;
var RolloutEvaluator = /** @class */ (function () {
    function RolloutEvaluator() {
    }
    RolloutEvaluator.prototype.Evaluate = function (config, key, defaultValue, User) {
        if (!config || !config.JSONConfig) {
            return defaultValue;
        }
        var json = JSON.parse(config.JSONConfig);
        if (!json[key]) {
            return defaultValue;
        }
        var result;
        if (User) {
            result = this.EvaluateRules(json[key].RolloutRules, User);
            if (result == null) {
                result = this.EvaluateVariations(json[key].RolloutPercentageItems, key, User);
            }
        }
        return result == null ? json[key].Value : result;
    };
    RolloutEvaluator.prototype.EvaluateRules = function (rolloutRules, User) {
        if (rolloutRules && rolloutRules.length > 0) {
            var _loop_1 = function (i) {
                var rule = rolloutRules[i];
                var ca = this_1.GetUserAttribute(User, rule.ComparisonAttribute);
                switch (rule.Comparator) {
                    case 0: // in
                        var cvs = rule.ComparisonValue.split(",");
                        for (var ci = 0; ci < cvs.length; ci++) {
                            if (cvs[ci].trim() === ca) {
                                return { value: rule.Value };
                            }
                        }
                        break;
                    case 1: // notIn
                        if (!rule.ComparisonValue.split(",").some(function (e) {
                            if (e.trim() === ca) {
                                return true;
                            }
                            return false;
                        })) {
                            return { value: rule.Value };
                        }
                        break;
                    case 2: // contains
                        if (ca.search(rule.ComparisonValue) !== -1) {
                            return { value: rule.Value };
                        }
                        break;
                    case 3: // not contains
                        if (ca.search(rule.ComparisonValue) === -1) {
                            return { value: rule.Value };
                        }
                        break;
                    default:
                        break;
                }
            };
            var this_1 = this;
            for (var i = 0; i < rolloutRules.length; i++) {
                var state_1 = _loop_1(i);
                if (typeof state_1 === "object")
                    return state_1.value;
            }
        }
        return null;
    };
    RolloutEvaluator.prototype.EvaluateVariations = function (rolloutPercentageItems, key, User, ro) {
        if (rolloutPercentageItems && rolloutPercentageItems.length > 0) {
            var hashCandidate = key + User.identifier;
            var hashValue = sha1(hashCandidate).substring(0, 12);
            var hashScale = parseInt(hashValue, 16) % 100;
            var bucket = 0;
            for (var i = 0; i < rolloutPercentageItems.length; i++) {
                var variation = rolloutPercentageItems[i];
                bucket += +variation.Percentage;
                if (hashScale < bucket) {
                    return variation.Value;
                }
            }
        }
        return null;
    };
    RolloutEvaluator.prototype.GetUserAttribute = function (User, attribute) {
        switch (attribute) {
            case "Identifier":
                return User.identifier;
            case "Email":
                return User.email;
            case "Country":
                return User.country;
            default:
                return User.custom[attribute];
        }
    };
    return RolloutEvaluator;
}());
exports.RolloutEvaluator = RolloutEvaluator;
