"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ConfigCatClientImpl_1 = require("./ConfigCatClientImpl");
var ConfigCatClientConfiguration_1 = require("./ConfigCatClientConfiguration");
/** Create an instance of ConfigCatClient and setup AutoPool mode with default settings */
function createClient(apiKey) {
    return createClientWithAutoPoll(apiKey, new ConfigCatClientConfiguration_1.AutoPollConfiguration());
}
exports.createClient = createClient;
/**
 * Create an instance of ConfigCatClient and setup AutoPoll mode
 * @param {string} apiKey - ApiKey to access your configuration.
 * @param config - Configuration for autoPoll mode
 */
function createClientWithAutoPoll(apiKey, config) {
    var c = new ConfigCatClientConfiguration_1.AutoPollConfiguration();
    if (config && config.maxInitWaitTimeSeconds) {
        c.maxInitWaitTimeSeconds = config.maxInitWaitTimeSeconds;
    }
    if (config && config.pollIntervalSeconds) {
        c.pollIntervalSeconds = config.pollIntervalSeconds;
    }
    if (config && config.configChanged) {
        c.configChanged = config.configChanged;
    }
    var result = new ConfigCatClientImpl_1.ConfigCatClientImpl(apiKey, c);
    return result;
}
exports.createClientWithAutoPoll = createClientWithAutoPoll;
/**
 * Create an instance of ConfigCatClient and setup ManulaPoll mode
 * @param {string} apiKey - ApiKey to access your configuration.
 * @param config - Configuration for manualPoll mode
 */
function createClientWithManualPoll(apiKey, config) {
    var c = new ConfigCatClientConfiguration_1.ManualPollConfiguration();
    var result = new ConfigCatClientImpl_1.ConfigCatClientImpl(apiKey, c);
    return result;
}
exports.createClientWithManualPoll = createClientWithManualPoll;
/**
 * Create an instance of ConfigCatClient and setup LazyLoad mode
 * @param {string} apiKey - ApiKey to access your configuration.
 * @param config - Configuration for lazyLoad mode
 */
function createClientWithLazyLoad(apiKey, config) {
    var c = new ConfigCatClientConfiguration_1.LazyLoadConfiguration();
    if (config && config.cacheTimeToLiveSeconds) {
        c.cacheTimeToLiveSeconds = config.cacheTimeToLiveSeconds;
    }
    var result = new ConfigCatClientImpl_1.ConfigCatClientImpl(apiKey, c);
    return result;
}
exports.createClientWithLazyLoad = createClientWithLazyLoad;
exports.CONFIG_CHANGED_EVENT = ConfigCatClientConfiguration_1.AutoPollConfiguration.CONFIG_CHANGED_EVENT;
